@@ -1,12 +1,12 @@
 package RDF::RDFa::Linter::Error;
 
 use 5.008;
-use base qw'RDF::RDFa::Generator::HTML::Pretty::Note';
-use common::sense;
+use base qw(RDF::RDFa::Generator::HTML::Pretty::Note);
+use strict;
 use constant XHTML_NS => 'http://www.w3.org/1999/xhtml';
-use XML::LibXML qw':all';
+use XML::LibXML qw(:all);
 
-our $VERSION = '0.052';
+our $VERSION = '0.053';
 
 sub new
 {
